OC.L10N.register(
    "contacts",
    {
    "Invalid image" : "غلط تصویر",
    "Loading" : "Loading",
    "Name" : "اسم",
    "Title" : "عنوان",
    "Download" : "ڈاؤن لوڈ",
    "Delete" : "حذف کریں",
    "Cancel" : "منسوخ کریں",
    "Rename" : "Rename",
    "can edit" : "تبدیل کر سکے ھیں",
    "Notes" : "Notes",
    "Location" : "مقام",
    "Work" : "کام",
    "Other" : "دیگر",
    "Birthday" : "سالگرہ",
    "Email" : "email"
},
"nplurals=2; plural=(n != 1);");
